==> nezha-engine-api-1.2.12-20240305.024431-1-sources.jar: cn/com/duiba/nezha/engine/api/enums/DeepTfServer.java <==
package cn.com.duiba.nezha.engine.api.enums;

public enum DeepTfServer {

    XDEEP_FM_CTR_105_NEW("xdeepfm-ctr-105", "10.222.52.229", 9000),
    XDEEP_FM_BCVR_105_NEW("xdeepfm-bcvr-105", "10.222.52.227", 9000),

    mid_adx_advert_cvr_v005("mid-adx-advert-cvr-v005", "10.222.54.0", 9000),

    E2E_DCVR_DEEPFM_V001("e2e-dcvr-deepfm-v001", "local", 9000),

    DCVR_DELAY_MODEL_V001("dcvr-delay-model-v001", "local", 9000),
    DCVR_V003("dcvr-v003", "local", 9000),
    //新增双出价模型
    MID_AD_DCVR_V001("mid-ad-dcvr-v0629", "local", 9000),

    E2E_DCVR_DNN_V027("e2e-dcvr-dnn-v027", "local", 9000),

    MMOE_E2E_BCVR_V001("mmoe-e2e-bcvr-v001", "10.222.54.23", 9000),

    MMOE_E2E_BCVR_V000("mmoe-e2e-bcvr-v000", "local", 9000),

    MID_ADX_ADVERT_CVR_V008("mid-adx-advert-cvr-v008", "local", 9000),

    MID_ADX_ADVERT_CVR_V009("mid-adx-advert-cvr-v009", "local", 9000),

    MID_ADX_ADVERT_CVR_V010("mid-adx-advert-cvr-v010", "local", 9000),

    MID_ADX_ADVERT_CVR_V011("mid-adx-advert-cvr-v011", "local", 9000),
    MID_ADX_ADVERT_CVR_V012("mid-adx-advert-cvr-v012", "local", 9000),

    FM_E2E_BCVR_403_YD("fm-e2e-bcvr-403-yd", "local", 9000),

    FM_E2E_BCVR_412_YD("fm-e2e-bcvr-412-yd", "local", 9000),

    MID_LANDPAGE_CTR_V001("mid-landpage-ctr-v001", "local", 9000),
    MID_AD_TRADE_DCVR_V001("mid-ad-dcvr-v1025", "local", 9000),
    MID_AD_TRADE_DCVR_V002("mid-ad-dcvr-v1212", "local", 9000),
    MID_AD_TRADE_DCVR_V003("mid-ad-dcvr-v240117", "local", 9000),


    ;

    private String host;
    private Integer port;
    private String modelKey;

    DeepTfServer(String modelKey, String host, Integer port) {
        this.host = host;
        this.port = port;
        this.modelKey = modelKey;
    }

    public String getHost() {
        return host;
    }

    public Integer getPort() {
        return port;
    }

    public String getModelKey() {
        return modelKey;
    }
}

==> nezha-engine-api-1.2.31-sources.jar: cn/com/duiba/nezha/engine/api/enums/DeepTfServer.java <==
package cn.com.duiba.nezha.engine.api.enums;

public enum DeepTfServer {

    XDEEP_FM_CTR_105_NEW("xdeepfm-ctr-105", "10.222.52.229", 9000),
    XDEEP_FM_BCVR_105_NEW("xdeepfm-bcvr-105", "10.222.52.227", 9000),

    mid_adx_advert_cvr_v005("mid-adx-advert-cvr-v005", "10.222.54.0", 9000),

    E2E_DCVR_DEEPFM_V001("e2e-dcvr-deepfm-v001", "local", 9000),

    DCVR_DELAY_MODEL_V001("dcvr-delay-model-v001", "local", 9000),
    DCVR_V003("dcvr-v003", "local", 9000),
    //新增双出价模型
    MID_AD_DCVR_V001("mid-ad-dcvr-v0629", "local", 9000),

    E2E_DCVR_DNN_V027("e2e-dcvr-dnn-v027", "local", 9000),

    MMOE_E2E_BCVR_V001("mmoe-e2e-bcvr-v001", "10.222.54.23", 9000),

    MMOE_E2E_BCVR_V000("mmoe-e2e-bcvr-v000", "local", 9000),

    MID_ADX_ADVERT_CVR_V008("mid-adx-advert-cvr-v008", "local", 9000),

    MID_ADX_ADVERT_CVR_V009("mid-adx-advert-cvr-v009", "local", 9000),

    MID_ADX_ADVERT_CVR_V010("mid-adx-advert-cvr-v010", "local", 9000),

    MID_ADX_ADVERT_CVR_V011("mid-adx-advert-cvr-v011", "local", 9000),
    MID_ADX_ADVERT_CVR_V012("mid-adx-advert-cvr-v012", "local", 9000),

    FM_E2E_BCVR_403_YD("fm-e2e-bcvr-403-yd", "local", 9000),

    FM_E2E_BCVR_412_YD("fm-e2e-bcvr-412-yd", "local", 9000),

    MID_LANDPAGE_CTR_V001("mid-landpage-ctr-v001", "local", 9000),
    MID_AD_TRADE_DCVR_V001("mid-ad-dcvr-v1025", "local", 9000),
    MID_AD_TRADE_DCVR_V002("mid-ad-dcvr-v1212", "local", 9000),
    MID_AD_TRADE_DCVR_V003("mid-ad-dcvr-rand-v240611", "local", 9000),
    MID_AD_DCVR_V240612("mid-ad-dcvr-v240612", "local", 9000),
    MID_AD_OPERATOR_DCVR_V003("mid-ad-dcvr-v240415", "local", 9000),


    ;

    private String host;
    private Integer port;
    private String modelKey;

    DeepTfServer(String modelKey, String host, Integer port) {
        this.host = host;
        this.port = port;
        this.modelKey = modelKey;
    }

    public String getHost() {
        return host;
    }

    public Integer getPort() {
        return port;
    }

    public String getModelKey() {
        return modelKey;
    }
}
